"""
Convert KickAssembler .prg object code to Atari 8 Bit .xex format
"""
import sys

def process(source):
    """Convert bytearray in .prg format to .xex format"""
    xex = bytearray(b'\xff\xff')
    xex.append(source[0])
    xex.append(source[1])
    xex_end = (source[1] * 255) + source[0] + (len(source) - 2)
    xex.append(int(xex_end % 255))
    xex.append(int(xex_end / 255))
    return xex + source[2:]

def convert():
    """Convert stdin .prg to stdout .xex"""
    try:
        data = sys.stdin.buffer.read()
    except AttributeError:
        sys.exit('error reading from stdin')
    output = process(data)
    sys.stdout.buffer.write(output)

if __name__ == '__main__':

    convert()



"""Package code"""
from setuptools import setup, setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='prg2xex',
      version='0.0.2',
      description='Convert KickAssembler prg object code to Atari 8 Bit xex file',
      url='https://github.com/peckhamdata/prg2xex',
      author='worldofchris',
      author_email='chris@worldofchris.com',
      long_description=long_description,
      long_description_content_type="text/markdown",
      license='MIT',
      packages=setuptools.find_packages(),
      scripts=['bin/prg2xex'],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent"],
      install_requires=['pytest'],
      python_requires='>=3.6')
